==> react-molecule-accordion-2.9.0.tgz: package/lib/AccordionItem.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { forwardRef, Fragment } from 'react';
import { isFragment } from 'react-is';
import cx from 'classnames';
import PropTypes from 'prop-types';
import Poly from '@s-ui/react-primitive-polymorphic-element';
import { MoleculeAccordionItemHeader as AccordionItemHeader, MoleculeAccordionItemPanel as AccordionItemPanel } from './index.js';
import { BASE_CLASS_ITEM, HEADER_ICON_POSITION } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var AccordionItem = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$as = _ref.as,
    As = _ref$as === void 0 ? Fragment : _ref$as,
    headerAs = _ref.headerAs,
    headerLevel = _ref.headerLevel,
    panelAs = _ref.panelAs,
    id = _ref.id,
    header = _ref.header,
    children = _ref.children,
    headerIcon = _ref.headerIcon,
    headerIconPosition = _ref.headerIconPosition,
    disabled = _ref.disabled,
    isExpanded = _ref.isExpanded,
    value = _ref.value,
    label = _ref.label,
    onClick = _ref.onClick,
    content = _ref.content,
    maxHeight = _ref.maxHeight;
  var headerId = "header-" + (id === undefined ? value : id);
  var panelId = "panel-" + (id === undefined ? value : id);
  return /*#__PURE__*/_jsxs(Poly, _extends({
    as: As
  }, !isFragment( /*#__PURE__*/_jsx(As, {})) && {
    ref: forwardedRef,
    className: cx(BASE_CLASS_ITEM)
  }, {
    children: [/*#__PURE__*/_jsx(AccordionItemHeader, {
      as: headerAs,
      level: headerLevel,
      disabled: disabled,
      id: headerId,
      panelId: panelId,
      value: value,
      icon: headerIcon,
      iconPosition: headerIconPosition,
      label: label,
      onClick: onClick,
      children: header
    }), /*#__PURE__*/_jsx(AccordionItemPanel, {
      as: panelAs,
      id: panelId,
      headerId: headerId,
      isExpanded: isExpanded,
      disabled: disabled,
      value: value,
      content: content,
      maxHeight: maxHeight,
      children: children
    })]
  }));
});
AccordionItem.displayName = 'AccordionItem';
export default AccordionItem;

==> react-molecule-accordion-2.12.0.tgz: package/lib/AccordionItem.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { forwardRef, Fragment } from 'react';
import { isFragment } from 'react-is';
import cx from 'classnames';
import PropTypes from 'prop-types';
import Poly from '@s-ui/react-primitive-polymorphic-element';
import { MoleculeAccordionItemHeader as AccordionItemHeader, MoleculeAccordionItemPanel as AccordionItemPanel } from './index.js';
import { BASE_CLASS_ITEM, HEADER_ICON_POSITION, HEADER_LABEL_WRAPS } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var AccordionItem = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$as = _ref.as,
    As = _ref$as === void 0 ? Fragment : _ref$as,
    headerAs = _ref.headerAs,
    headerLevel = _ref.headerLevel,
    panelAs = _ref.panelAs,
    id = _ref.id,
    header = _ref.header,
    children = _ref.children,
    headerIcon = _ref.headerIcon,
    headerIconPosition = _ref.headerIconPosition,
    headerLabelWrap = _ref.headerLabelWrap,
    disabled = _ref.disabled,
    isExpanded = _ref.isExpanded,
    value = _ref.value,
    label = _ref.label,
    onClick = _ref.onClick,
    content = _ref.content,
    maxHeight = _ref.maxHeight;
  var headerId = "header-" + (id === undefined ? value : id);
  var panelId = "panel-" + (id === undefined ? value : id);
  return /*#__PURE__*/_jsxs(Poly, _extends({
    as: As
  }, !isFragment( /*#__PURE__*/_jsx(As, {})) && {
    ref: forwardedRef,
    className: cx(BASE_CLASS_ITEM)
  }, {
    children: [/*#__PURE__*/_jsx(AccordionItemHeader, {
      as: headerAs,
      level: headerLevel,
      disabled: disabled,
      id: headerId,
      panelId: panelId,
      value: value,
      icon: headerIcon,
      iconPosition: headerIconPosition,
      label: label,
      labelWrap: headerLabelWrap,
      onClick: onClick,
      children: header
    }), /*#__PURE__*/_jsx(AccordionItemPanel, {
      as: panelAs,
      id: panelId,
      headerId: headerId,
      isExpanded: isExpanded,
      disabled: disabled,
      value: value,
      content: content,
      maxHeight: maxHeight,
      children: children
    })]
  }));
});
AccordionItem.displayName = 'AccordionItem';
export default AccordionItem;
